@@ -8,7 +8,7 @@ test_that("convert ECG from MUSE XML format to WFDB", {
 	expect_length(ecg, 3)
 	expect_length(ecg$signal, 13)
 	expect_equal(nrow(ecg$signal), 5000)
-	expect_s3_class(ecg, "egm")
+	expect_s3_class(ecg, c("egm", "ecg"))
 	expect_s3_class(ecg$signal, "signal_table")
 	expect_s3_class(ecg$signal, "data.table")
 	expect_s3_class(ecg$header, "header_table")
